@@ -22,6 +22,18 @@
 #define PATH_MAILLOG	"/var/adm/syslog/mail.log"
 #endif
 
+#ifdef TRU64
+#define HAVE_GETRUSAGE
+#define SIZEOF_IS_LONG_INT
+#define PATH_TMP	"/tmp"
+#define PATH_VAR_TMP	"/var/tmp"
+#define PATH_PASSWD	"/etc/passwd"
+#define PATH_WTMP	"/var/adm/wtmp"
+#define PATH_UTMP	"/var/adm/utmp"
+#define PATH_SYSLOG	"/var/adm/syslog.dated/current/daemon.log"
+#define PATH_MAILLOG	"/var/adm/syslog.dated/current/mail.log"
+#endif
+
 #ifdef SUNOS
 #define HAVE_GETRUSAGE
 #define PID_T_IS_LONG_INT
