@@ -18,6 +18,17 @@
 #include "config.h"
 #include "prngd.h"
 
+#ifdef NEXTSTEP3
+/* not supported */
+#define SA_RESTART 0
+
+/* select */
+#include <libc.h>
+
+/* in ansi string.h but undefined in -posix */
+# define bzero(b,len) memset(b,0,len)
+#endif
+
 static pid_t gatherer_pid = -1;
 
 typedef enum
